@@ -1,8 +1,8 @@
 ## File Name: gdina_calc_prob.R
-## File Version: 0.17
+## File Version: 0.18
 
-gdina_calc_prob <- function( progress, iter, disp, J, L, aggr.attr.patt, Mj, delta,
-        linkfct)
+gdina_calc_prob <- function( progress, iter, disp, J, L, aggr.attr.patt, Mj, 
+        delta, linkfct)
 {
     if ( progress ){
         cat(disp)
@@ -12,17 +12,6 @@ gdina_calc_prob <- function( progress, iter, disp, J, L, aggr.attr.patt, Mj, del
     #---- calculate P(X_j | alpha_l )
     for (jj in 1:J){
         ajj <- aggr.attr.patt[[jj]]
-
-        mjjj <- Mj[[jj]][[1]][ ajj, ]
-        djj <- matrix( delta[[jj]], nrow=L, ncol=length(delta[[jj]]), byrow=TRUE )
-        pj1[jj,] <- rowSums( mjjj * djj )
-        if (linkfct=="logit"){
-            pj1[jj,] <- stats::plogis( pj1[jj,] )
-        }
-        if (linkfct=="log"){
-            pj1[jj,] <- exp( pj1[jj,] )
-        }
-
         mjjj <- Mj[[jj]][[1]]
         djj <- cdm_matrix2( delta[[jj]], nrow=nrow(mjjj) )
         pj11 <- rowSums( mjjj * djj )
@@ -30,7 +19,7 @@ gdina_calc_prob <- function( progress, iter, disp, J, L, aggr.attr.patt, Mj, del
             pj11 <- stats::plogis( pj11 )
         }
         if (linkfct=="log"){
-            pj11 <- exp( pj11 )
+            pj11 <- exp(pj11)
         }
         pj1[jj,] <- pj11[ ajj ]
     }
