@@ -1,8 +1,10 @@
 ## File Name: gdina_mstep_mono_constraints_penalty.R
-## File Version: 0.04
+## File Version: 0.06
 
 gdina_mstep_mono_constraints_penalty <- function(x)
 {
-    y <- ifelse( x < 0, x^2, 0 )
+    eps <- 1e-3
+    # y <- ifelse( x < 0, x^2, 0 )
+    y <- ifelse( x < 0, sqrt(x^2+eps), 0 )
     return(y)
 }
