@@ -1,9 +1,9 @@
 ## File Name: reglca_fit_probabilities.R
-## File Version: 0.428
+## File Version: 0.438
 
 reglca_fit_probabilities <- function( freq, pi_class, lambda, parm_init=NULL, regular_type="scad",
     h=1E-4, maxit=100, conv=1E-5, cd_steps=5, max_increment=1, verbose=TRUE, prob_min=0,
-    ii=NULL )
+    ii=NULL, iter=NULL )
 {
     #--- order frequencies
     NP <- length(freq)
@@ -32,7 +32,8 @@ reglca_fit_probabilities <- function( freq, pi_class, lambda, parm_init=NULL, re
         for (pp in 1:NP){
             parm <- reglca_update_parameter( parm=parm, pp=pp, C=C, W=W, h=h, lambda=lambda,
                         regular_type=regular_type, cd_steps=cd_steps, conv=conv,
-                        max_increment=max_increment, vt=NULL, prob_min=prob_min, ii=ii)
+                        max_increment=max_increment, vt=NULL, prob_min=prob_min, ii=ii,
+                        iter=iter)
         }
         #-- normalize probabilities
         parm <- reglca_normalize_probabilities(parm=parm)
